#!/bin/bash
#
# 96zdev-live/parse-zdev-live.sh
#   Parse the kernel command line for rd.zdev kernel parameters. These
#   parameters are evaluated and used to configure z Systems specific devices
#   with chzdev(8), especially for use on live/installation type media.
#   Note: this is only active on no-hostonly initrds (by default).
#
# Format:
#   rd.zdev=TYPE,DEVICE[,SETTINGS]
#
#     where
#
#   TYPE:      all device types supported by chzdev(8), like qeth and dasd
#   DEVICE:    device specification as supported by chzdev(8) '--enable',
#              with the exception of specifying multiple devices, which
#              need to be separated by commas.  Channel group members
#              (or zFCP parameters) in turn are separated by colons.
#   SETTINGS:  Settings are positional arguments of chzdev in the form
#              KEY=VALUE separated by commas.

zdev_enable="--persistent --enable"
zdev_base_args="--yes --no-root-update --no-settle"

for zdevs in $(getargs rd.zdev) ; do
    IFS=',' read -r -a zdev <<< "$zdevs"
    if [ -n "$zdev" ] && [ "$zdev" = "no-auto" -o "$zdev" = "auto" ] ; then
        : # ignore, as it's handled by 95zdev
    elif [ -z "$zdev" ] || [ -z "${zdev[1]}" ] ; then
        warn "Unsupported usage of rd.zdev=$zdevs"
    else
        info "+ chzdev $zdev_enable [...] ${zdev[@]}"
        chzdev $zdev_enable $zdev_base_args "${zdev[@]}"
    fi
done

